@@ -18,7 +18,7 @@ if __name__ == "__main__":
     newest = datetime.now()
     oldest = newest - timedelta(days=1)  # datetime one week ago = the finish line
 
-    scores = darthvader.summary_interval(
+    scores = darthvader.news_summary(
         *args, oldest, newest
     )  # latest date to get news from
     print("Total\n--")
